@@ -2,6 +2,14 @@
 import sqlalchemy
 
 
+class TableNotFoundException(Exception):
+    pass
+
+
+class ColumnNotFoundException(Exception):
+    pass
+
+
 class SqlColumn(object):
     def build_column(self, sql_table):
         raise NotImplementedError()
@@ -55,6 +63,8 @@ class SimpleQueryMeta(QueryMeta):
             for c in self.columns:
                 if c.column_name in groups:
                     groups.remove(c.column_name)
+                elif c.alias in groups:
+                    groups.remove(c.alias)
 
             for g in groups:
                 self.columns.append(SimpleSqlColumn(g, aggregate_fn=None, alias=g))
@@ -65,14 +75,26 @@ class SimpleQueryMeta(QueryMeta):
 
     def _build_query(self, metadata):
         self._check()
-        table = metadata.tables[self.table_name]
-        query = sqlalchemy.select()
-        if self.group_by:
-            for group_key in self.group_by:
-                query.append_group_by(table.c[group_key])
+        try:
+            table = metadata.tables[self.table_name]
+        except KeyError:
+            raise TableNotFoundException("Unable to query table, table not found: %s" % self.table_name)
 
-        for c in self.columns:
-            query.append_column(c.build_column(table))
+        try:
+            query = sqlalchemy.select()
+            if self.group_by:
+                cols = [c.column_name for c in self.columns]
+                alias = [c.alias for c in self.columns]
+                for group_key in self.group_by:
+                    if group_key in cols:
+                        query.append_group_by(table.c[group_key])
+                    elif group_key in alias:
+                        query.append_group_by(group_key)
+
+            for c in self.columns:
+                query.append_column(c.build_column(table))
+        except KeyError as e:
+            raise ColumnNotFoundException("Missing column in table (%s): %s" % (self.table_name, e))
 
         if self.filters:
             for filter in self.filters:
